==> igniteui-react-charts-16.6.8.tgz: package/ES5/Stacked100SplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StackedSplineSeries } from "./StackedSplineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core/ES5/type";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
/**
 * @hidden
 */
var Stacked100SplineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(Stacked100SplineSeries, _super);
    function Stacked100SplineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100SplineSeries.$;
        return _this;
    }
    Stacked100SplineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.i6(false);
    };
    Stacked100SplineSeries.prototype.pe = function () {
        _super.prototype.pe.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100SplineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nv;
        },
        enumerable: true,
        configurable: true
    });
    Stacked100SplineSeries.$t = markType(Stacked100SplineSeries, 'Stacked100SplineSeries', StackedSplineSeries.$, [IStacked100Series_$type]);
    return Stacked100SplineSeries;
}(StackedSplineSeries));
export { Stacked100SplineSeries };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/Stacked100SplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StackedSplineSeries } from "./StackedSplineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core/ES5/type";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
/**
 * @hidden
 */
var Stacked100SplineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(Stacked100SplineSeries, _super);
    function Stacked100SplineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100SplineSeries.$;
        return _this;
    }
    Stacked100SplineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.jd(false);
    };
    Stacked100SplineSeries.prototype.pl = function () {
        _super.prototype.pl.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100SplineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.n2;
        },
        enumerable: true,
        configurable: true
    });
    Stacked100SplineSeries.$t = markType(Stacked100SplineSeries, 'Stacked100SplineSeries', StackedSplineSeries.$, [IStacked100Series_$type]);
    return Stacked100SplineSeries;
}(StackedSplineSeries));
export { Stacked100SplineSeries };
